﻿/* ***********************************************************************
The templates and the materials presented in this article
as well as the underlying classes in the package
edu.uriship.math.grapher3d were created by

Barbara Kaskosz of the University of Rhode Island
(bkaskosz@math.uri.edu) and
Douglas E. Ensley of Shippensburg University
(deensl@ship.edu).

The materials are a part of the ongoing series 
"Flash Tools for Developers" by the authors.

This work is supported in part by the National Science Foundation
under the grant DUE-0535327.

Feel free to use and modify the templates and the classes to create
your own Flash applications for educational purposes under the
following two conditions:

1) Please include a line acknowledging this work and the authors
with your application. 

2) If you choose to modify the classes in the package 
edu.uriship.math.grapher3d, put them into a package different from
the original. In this case too, please acknowledge this work.

Last modified: May 7, 2006

************************************************************************ */

import edu.uriship.math.grapher3d.MatrixUtils;

class edu.uriship.math.grapher3d.GraphingBoard3D {
	
	private var nBoardSize:Number;
	
	private var nCubeSize:Number;
	
	private var mcContainer:MovieClip;
	
	private var mcGraphHolder:MovieClip;
	
	private var patches:MovieClip;
	
	private var mcBorder:MovieClip;
	
	private var mcBack:MovieClip;
	
	private var side1:MovieClip;
	
	private var side2:MovieClip;
	
	private var side3:MovieClip;
	
	private var side4:MovieClip;
	
	private var side5:MovieClip;
	
	private var side6:MovieClip;
	
	private var side7:MovieClip;
	
	private var side8:MovieClip;
	
	private var side9:MovieClip;
	
	private var side10:MovieClip;
	
	private var side11:MovieClip;
	
	private var side12:MovieClip;
	
	private var mcBoxHolder:MovieClip;
	
	private var mcMask:MovieClip;
	
	private var ErrorFormat:TextFormat; 
	
	private var ErrorBox:TextField;
	
	private var WaitBox:TextField;
	
	private var WaitFormat:TextFormat;
	
	private var xLabel:TextField;
	
	private var yLabel:TextField;
	
	private var zLabel:TextField;
	
	private var xminLabel:TextField;
	
	private var xmaxLabel:TextField;
	
	private var yminLabel:TextField;
	
	private var ymaxLabel:TextField;
	
	private var zminLabel:TextField;
	
	private var zmaxLabel:TextField;
	
	private var LabelsFormat:TextFormat;
	
	private var p1:Array;
	
	private var p2:Array;
	
	private var p3:Array;
	
	private var p4:Array;
	
	private var p5:Array;
	
	private var p6:Array;
	
	private var p7:Array;
	
	private var p8:Array;
	
	public var fLength:Number;
	
	public var nMesh:Number;
	
	public var nFrameColor:Number;
	
	public var nAxesFront:Number;
	
	public var nAxesBack:Number;
	
	private var funArray:Array;
	
	private var pixArray:Array;
	
	public var bShowFrame:Boolean;
	
	public var aTilesColors:Array;
	
	public var nOpacity:Number;
	
	
	public function GraphingBoard3D(x:Number,y:Number,b:Number,target:MovieClip,depth:Number){
		
		this.nBoardSize=b;
		
		this.nCubeSize=Math.round(0.28*nBoardSize);
		
		this.fLength=2000;
		
		this.nMesh=15;
	
	    this.nFrameColor=0x333333;
	
	    this.nAxesFront=0xCCCCCC;
	
	    this.nAxesBack=0x666666;
		
		this.nOpacity=100;
	
	    this.funArray=[];
	
	    this.pixArray=[];
	
	    this.bShowFrame=true;
	
	    this.aTilesColors=[];
		
		mcContainer=target.createEmptyMovieClip("container",depth);
		
		mcContainer._x=x;
		
		mcContainer._y=y;
		
		mcBorder=mcContainer.createEmptyMovieClip("border",3);
		
		mcBack=mcContainer.createEmptyMovieClip("back",1);
		
		mcBoxHolder=mcContainer.createEmptyMovieClip("boxholder",5);
		
		mcBoxHolder._x=nBoardSize/2;
		
		mcBoxHolder._y=nBoardSize/2;
		
		mcGraphHolder=mcContainer.createEmptyMovieClip("graphholder",4);
		
		mcGraphHolder._x=nBoardSize/2;
		
		mcGraphHolder._y=nBoardSize/2;
		
		side1=mcGraphHolder.createEmptyMovieClip("Side1",1);
		
		side2=mcGraphHolder.createEmptyMovieClip("Side2",2);
		
		side3=mcGraphHolder.createEmptyMovieClip("Side3",3);
		
		side4=mcGraphHolder.createEmptyMovieClip("Side4",4);
		
		side5=mcGraphHolder.createEmptyMovieClip("Side5",5);
		
		side6=mcGraphHolder.createEmptyMovieClip("Side6",6);
		
		side7=mcGraphHolder.createEmptyMovieClip("Side7",7);
		
		side8=mcGraphHolder.createEmptyMovieClip("Side8",8);
		
		side9=mcGraphHolder.createEmptyMovieClip("Side9",9);
		
		side10=mcGraphHolder.createEmptyMovieClip("Side10",10);
		
		side11=mcGraphHolder.createEmptyMovieClip("Side11",11);
		
		side12=mcGraphHolder.createEmptyMovieClip("Side12",12);
		
		patches=mcGraphHolder.createEmptyMovieClip("tiles",50);
		
		mcMask=mcContainer.createEmptyMovieClip("maskgraph",2);
		
		mcGraphHolder.setMask(mcMask);
		
	    drawBack(0x000000);
		
		drawBorder(0xFFFFFF);
		
		drawMask();
		
		createErrorBox();
		
		createWaitBox();
		
		createLabels();
		
		prepAxes();
		
		
	}
	
	public function getBoardSize():Number {
		
		return nBoardSize;
		
	}
	
	public function getCubeSize():Number {
		
		return nCubeSize;
		
	}
	
	public function setCubeSize(a:Number):Void {
		
		nCubeSize=a;
		
		prepAxes();
		
	}
	
	
	private function signum(a:Number,b:Number):Number {
	
	if(b-a>0){return 1;}
	else if(b-a<0){return -1;}
	else {return 0;}
	
      }
	
	private function prepAxes():Void {
	
	p1=[-nCubeSize,-nCubeSize,-nCubeSize];
	
	p2=[-nCubeSize,nCubeSize,-nCubeSize];
	
	p3=[-nCubeSize,nCubeSize,nCubeSize];
	
	p4=[nCubeSize,nCubeSize,nCubeSize];
	
	p5=[nCubeSize,nCubeSize,-nCubeSize];
	
	p6=[nCubeSize,-nCubeSize,-nCubeSize];
	
	p7=[-nCubeSize,-nCubeSize,nCubeSize];
	
	p8=[nCubeSize,-nCubeSize,nCubeSize];
	
     }

	
	
	
	private function createErrorBox(): Void {
		
		mcBoxHolder.createTextField("txtErrorBox",20,20-Math.round(nBoardSize/2),20-Math.round(nBoardSize/2),Math.round(nBoardSize)-40,Math.round(nBoardSize/2));
			
		ErrorBox=mcBoxHolder["txtErrorBox"];	
			
		ErrorBox.type="dynamic";
		
		ErrorBox.wordWrap=true;
		
		ErrorBox.border=true;
				
		ErrorBox.background=true;
		
		setErrorBoxFormat(0x000000,0x000000,0xCCCCCC,12);
			
		ErrorBox._visible=false;
				
	}
	
	
	
	public function setErrorBoxFormat(colo1:Number,colo2:Number,colo3:Number,size:Number): Void {
				
		ErrorFormat=new TextFormat("_sans",size,colo3);
		
		ErrorBox.backgroundColor=colo1;
		
		ErrorBox.borderColor=colo2;
		
		ErrorBox.setNewTextFormat(ErrorFormat);
			
	}
	
	
	public function setErrorBoxSizeAndPos(w:Number,h:Number,x:Number,y:Number): Void {
				
		ErrorBox._width=w;
		
		ErrorBox._height=h;
		
		ErrorBox._x=x-Math.round(nBoardSize/2);
		
		ErrorBox._y=y-Math.round(nBoardSize/2);
		
	}
	
	public function setErrorBoxVisible(b:Boolean):Void {
				
		ErrorBox._visible=b;
		
	}

	
	private function createWaitBox(): Void {
		
		mcBoxHolder.createTextField("txtWaitBox",10,Math.round(nBoardSize/2)-95,5-Math.round(nBoardSize/2),80,20);
			
		WaitBox=mcBoxHolder["txtWaitBox"];	
			
		WaitBox.type="dynamic";
		
		WaitBox.border=false;
				
		WaitBox.background=false;
		
		setWaitBoxFormat(0xFF9900,12,"Processing...");
			
		WaitBox._visible=false;
				
	}
	
	public function setWaitBoxFormat(colo:Number,size:Number,mes:String):Void {
				
		WaitFormat=new TextFormat("_sans",size,colo);
		
		WaitFormat.italic=true;
		
		WaitBox.text=mes;
		
		WaitBox.setTextFormat(WaitFormat);
		
	}
	
	public function setWaitBoxSizeAndPos(w:Number,h:Number,x:Number,y:Number):Void {
				
		WaitBox._width=w;
		
		WaitBox._height=h;
		
		WaitBox._x=x-Math.round(nBoardSize/2);
		
		WaitBox._y=y-Math.round(nBoardSize/2);
		
			
	}
	
	public function setWaitBoxVisible(b:Boolean):Void {
				
		WaitBox._visible=b;
		
	}
	
	private function createLabels(): Void {
		
		mcBoxHolder.createTextField("xlabel",1,0,0,18,18);
			
		xLabel=mcBoxHolder["xlabel"];	
			
		xLabel.type="dynamic";
		
		xLabel.border=false;
				
		xLabel.background=false;
		
		mcBoxHolder.createTextField("ylabel",2,20,0,18,18);
			
		yLabel=mcBoxHolder["ylabel"];	
			
		yLabel.type="dynamic";
		
		yLabel.border=false;
				
		yLabel.background=false;
		
		mcBoxHolder.createTextField("zlabel",3,40,0,18,18);
			
		zLabel=mcBoxHolder["zlabel"];	
			
		zLabel.type="dynamic";
		
		zLabel.border=false;
				
		zLabel.background=false;
		
		mcBoxHolder.createTextField("xminlabel",4,60,0,32,18);
			
		xminLabel=mcBoxHolder["xminlabel"];	
			
		xminLabel.type="dynamic";
		
		xminLabel.border=false;
				
		xminLabel.background=false;
		
		mcBoxHolder.createTextField("yminlabel",5,90,0,32,18);
			
		yminLabel=mcBoxHolder["yminlabel"];	
			
		yminLabel.type="dynamic";
		
		yminLabel.border=false;
				
		yminLabel.background=false;
		
		mcBoxHolder.createTextField("zminlabel",6,120,0,32,18);
			
		zminLabel=mcBoxHolder["zminlabel"];	
			
		zminLabel.type="dynamic";
		
		zminLabel.border=false;
				
		zminLabel.background=false;
		
		mcBoxHolder.createTextField("xmaxlabel",7,150,0,32,18);
			
		xmaxLabel=mcBoxHolder["xmaxlabel"];	
			
		xmaxLabel.type="dynamic";
		
		xmaxLabel.border=false;
				
		xmaxLabel.background=false;
		
		mcBoxHolder.createTextField("ymaxlabel",8,180,0,32,18);
			
		ymaxLabel=mcBoxHolder["ymaxlabel"];	
			
		ymaxLabel.type="dynamic";
		
		ymaxLabel.border=false;
				
		ymaxLabel.background=false;
		
		mcBoxHolder.createTextField("zmaxlabel",9,220,0,32,18);
			
		zmaxLabel=mcBoxHolder["zmaxlabel"];	
			
		zmaxLabel.type="dynamic";
		
		zmaxLabel.border=false;
				
		zmaxLabel.background=false;
		
		xLabel.text="x";
		
		yLabel.text="y";
		
		zLabel.text="z";
		
		xminLabel.text="xmin";
		
		yminLabel.text="ymin";
		
		zminLabel.text="zmin";
		
		xmaxLabel.text="xmax";
		
		ymaxLabel.text="ymax";
		
		zmaxLabel.text="zmax";
			
		setLabelsFormat(0xCCCCCC,11);
		
		xLabel._visible=true;
		
		yLabel._visible=true;
		
		zLabel._visible=true;
		
		xminLabel._visible=true;
		
		yminLabel._visible=true;
		
		zminLabel._visible=true;
		
		xmaxLabel._visible=true;
		
		ymaxLabel._visible=true;
		
		zmaxLabel._visible=true;
				
	}
	
	public function setLabelsFormat(colo:Number,size:Number): Void {
				
		LabelsFormat=new TextFormat("_sans",size,colo);
		
		xLabel.setTextFormat(LabelsFormat);
		
		yLabel.setTextFormat(LabelsFormat);
		
		zLabel.setTextFormat(LabelsFormat);
		
		xminLabel.setTextFormat(LabelsFormat);
		
		yminLabel.setTextFormat(LabelsFormat);
		
		zminLabel.setTextFormat(LabelsFormat);
		
		xmaxLabel.setTextFormat(LabelsFormat);
		
		ymaxLabel.setTextFormat(LabelsFormat);
		
		zmaxLabel.setTextFormat(LabelsFormat);
		
	}
	
	
	
	public function setBorderColor(colo:Number): Void {
		
		
		drawBorder(colo);
		
	}
	
	public function setBackColor(colo:Number): Void {
		
		drawBack(colo);
		
	}
	
	
	private function drawBorder(colo:Number): Void {
		
		mcBorder.clear();
		mcBorder.lineStyle(1,colo,100);
		mcBorder.moveTo(0,0);
		mcBorder.lineTo(0,nBoardSize);
		mcBorder.lineTo(nBoardSize,nBoardSize);
		mcBorder.lineTo(nBoardSize,0);
		mcBorder.lineTo(0,0);
		
	}
		
	
	private function drawBack(colo:Number): Void {
		
		mcBack.clear();
		mcBack.lineStyle(1,colo,100);
		mcBack.moveTo(0,0);
		mcBack.beginFill(colo,100);
		mcBack.lineTo(0,nBoardSize);
		mcBack.lineTo(nBoardSize,nBoardSize);
		mcBack.lineTo(nBoardSize,0);
		mcBack.lineTo(0,0);
		mcBack.endFill();
	
	}
	
	private function drawMask(): Void {
		
		mcMask.clear();		
		mcMask.moveTo(1,1);		
		mcMask.beginFill(0x666666,100);
		mcMask.lineTo(1,nBoardSize-1);
		mcMask.lineTo(nBoardSize-1,nBoardSize-1);
		mcMask.lineTo(nBoardSize-1,1);
		mcMask.lineTo(1,1);
		mcMask.endFill();
		
		
	}
	
	
	private function eraseGraphs(){
		
		
		for(var elem in mcGraphHolder){
			
			if(mcGraphHolder[elem] instanceof MovieClip){
			
			mcGraphHolder[elem].clear();
			
		}	
		
		}
		
		ErrorBox._visible=false;
			
	}
	
	
	public function setPixArray(A:Array): Void {
			
		pixArray=A;
		
	}
	
	public function setFunArray(A:Array): Void {
				
		funArray=A;
		
	}
	
	
	public function drawSurface(M:Array):Void {
		
		var j:Number;
		var i:Number;
		var avx:Number;
		var avy:Number;
		var avz:Number;
		var gcamer:Number;
		
	    var dispArray=[];
	
	    var depArray=[];
	
	    var n:Number;
	
	    var depLen:Number;
	
        patches.clear();
	
		
	if(pixArray.length>0){
		
	for(j=0;j<=nMesh;j++){
		
		dispArray[j]=[];
	     
		for(i=0;i<=nMesh; i++){
						
		pixArray[j][i]=MatrixUtils.MatrixByVector(M,pixArray[j][i]);
					
		dispArray[j][i]=MatrixUtils.projectPoint(pixArray[j][i],fLength);
		
		
	}
	

	}
	
	  
	for(j=0;j<nMesh;j++){	
	     
		for(i=0;i<nMesh;i++){
			
			 if(funArray[j][i][0]+funArray[j+1][i][0]+funArray[j][i+1][0]+funArray[j+1][i+1][0]==0){
				
			
   avx=(pixArray[j][i][0]+pixArray[j][i+1][0]+pixArray[j+1][i+1][0]+pixArray[j+1][i][0])/4;

   avy=(pixArray[j][i][1]+pixArray[j][i+1][1]+pixArray[j+1][i+1][1]+pixArray[j+1][i][1])/4;

   avz=(pixArray[j][i][2]+pixArray[j][i+1][2]+pixArray[j+1][i+1][2]+pixArray[j+1][i][2])/4;

   gcamer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
 
		depArray.push([gcamer,j,i]);
		
		  }
		}
		}
		
		depArray.sort(byDist);
		
		depLen=depArray.length;
		
		for(n=0;n<depLen;n++){
			
			j=depArray[n][1]; i=depArray[n][2];
		
				if(bShowFrame){
		
		         patches.lineStyle(0,nFrameColor,100);
		
				}
		
		patches.moveTo(dispArray[j][i][0],dispArray[j][i][1]);
		
		patches.beginFill(aTilesColors[j][i],nOpacity);
				
    	patches.lineTo(dispArray[j][i+1][0],dispArray[j][i+1][1]);		
						
		patches.lineTo(dispArray[j+1][i+1][0],dispArray[j+1][i+1][1]);
				
		patches.lineTo(dispArray[j+1][i][0],dispArray[j+1][i][1]);	
		
		patches.lineTo(dispArray[j][i][0],dispArray[j][i][1]);	
		
		patches.endFill();
			
	}
		}
		
		
		
	}
	
	
    private function byDist(v:Array,w:Array):Number {
	
	if (v[0]>w[0]){
		
		return -1;
		
	  } else if (v[0]<w[0]){
		
		return 1;
	
	   } else {
		
		return 0;
	  }
	  
  }

	
	
	
  public function drawAxes(M:Array):Void {
	
    var dp1:Array=[];
	var dp2:Array=[];
	var dp3:Array=[];
	var dp4:Array=[];
	var dp5:Array=[];
	var dp6:Array=[];
	var dp7:Array=[];
	var dp8:Array=[];
	
	var k:Number;
	
	var avx:Number;
	var avy:Number;
	var avz:Number;
	
	var mid1:Number;
	var mid2:Number;
	var mid3:Number;
	var mid4:Number;
	var mid5:Number;
	var mid6:Number;
	
	var index1:Number=0;
	var index2:Number=0;
	var index3:Number=0;
	var index4:Number=0;
	var index5:Number=0;
	var index6:Number=0;
	var index7:Number=0;
	var index8:Number=0;
	var index9:Number=0;
	var index10:Number=0;
	var index11:Number=0;
	var index12:Number=0;
	
	var camer:Number;
	
	var mids:Array=[];
	
	for(k=1;k<=12;k++){
		
	this["side"+k].clear();
	
	}
	
	p1=MatrixUtils.MatrixByVector(M,p1);
	
	dp1=MatrixUtils.projectPoint(p1,fLength);
	
	p2=MatrixUtils.MatrixByVector(M,p2);
	
	dp2=MatrixUtils.projectPoint(p2,fLength);
	
	p3=MatrixUtils.MatrixByVector(M,p3);
	
	dp3=MatrixUtils.projectPoint(p3,fLength);
	
	p4=MatrixUtils.MatrixByVector(M,p4);
	
	dp4=MatrixUtils.projectPoint(p4,fLength);
	
	p5=MatrixUtils.MatrixByVector(M,p5);
	
	dp5=MatrixUtils.projectPoint(p5,fLength);
	
	p6=MatrixUtils.MatrixByVector(M,p6);
	
	dp6=MatrixUtils.projectPoint(p6,fLength);
	
	p7=MatrixUtils.MatrixByVector(M,p7);
	
	dp7=MatrixUtils.projectPoint(p7,fLength);
	
	p8=MatrixUtils.MatrixByVector(M,p8);
	
	dp8=MatrixUtils.projectPoint(p8,fLength);
	
	yLabel._x=(dp2[0]+dp5[0])/2;
	
	yLabel._y=(dp2[1]+dp5[1])/2;
	
	yminLabel._x=dp2[0]+signum(dp2[0],dp5[0])*6;
	yminLabel._y=dp2[1]+signum(dp2[1],dp5[1])*10;
	ymaxLabel._x=dp5[0]-signum(dp2[0],dp5[0])*2;
	ymaxLabel._y=dp5[1]-signum(dp2[1],dp5[1])*2;
	
	xLabel._x=(dp2[0]+dp3[0])/2;
	
	xLabel._y=(dp2[1]+dp3[1])/2;
	
	xminLabel._x=dp2[0]+signum(dp2[0],dp3[0])*2;
	xminLabel._y=dp2[1]+signum(dp2[1],dp3[1])*2;
	
	xmaxLabel._x=dp3[0]-signum(dp2[0],dp3[0])*2;
	xmaxLabel._y=dp3[1]-signum(dp2[1],dp3[1])*2;
	
	zLabel._x=(dp2[0]+dp1[0])/2;
	
	zLabel._y=(dp2[1]+dp1[1])/2;
	
	zminLabel._x=dp2[0]+signum(dp2[0],dp1[0])*8;
	zminLabel._y=dp2[1]+signum(dp2[1],dp1[1])*15;
	zmaxLabel._x=dp1[0]-signum(dp2[0],dp1[0])*2;
	zmaxLabel._y=dp1[1]-signum(dp2[1],dp1[1])*2;
	
	
	avx=(p7[0]+p8[0]+p3[0]+p4[0])/4; 
	
	avy=(p7[1]+p8[1]+p3[1]+p4[1])/4; 
	
	avz=(p7[2]+p8[2]+p3[2]+p4[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid1=camer;
	
	avx=(p8[0]+p6[0]+p4[0]+p5[0])/4; 
	
	avy=(p8[1]+p6[1]+p4[1]+p5[1])/4; 
	
	avz=(p8[2]+p6[2]+p4[2]+p5[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid2=camer;
	
	avx=(p1[0]+p6[0]+p2[0]+p5[0])/4; 
	
	avy=(p1[1]+p6[1]+p2[1]+p5[1])/4; 
	
	avz=(p1[2]+p6[2]+p2[2]+p5[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid3=camer;
	
	avx=(p1[0]+p2[0]+p3[0]+p7[0])/4; 
	
	avy=(p1[1]+p2[1]+p3[1]+p7[1])/4; 
	
	avz=(p1[2]+p2[2]+p3[2]+p7[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid4=camer;
	
	avx=(p8[0]+p6[0]+p1[0]+p7[0])/4; 
	
	avy=(p8[1]+p6[1]+p1[1]+p7[1])/4; 
	
	avz=(p8[2]+p6[2]+p1[2]+p7[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid5=camer;
	
	avx=(p2[0]+p3[0]+p4[0]+p5[0])/4; 
	
	avy=(p2[1]+p3[1]+p4[1]+p5[1])/4; 
	
	avz=(p2[2]+p3[2]+p4[2]+p5[2])/4;
	
	camer=Math.sqrt(Math.pow(avx,2)+Math.pow(avy,2)+Math.pow(fLength-avz,2));
    
	mid6=camer;
	
	mids=[mid1,mid2,mid3,mid4,mid5,mid6];
	
	mids.sort(Array.NUMERIC);
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid3 || mids[k]==mid4){
			
			index1=1;
			
		}
		
	}
	
	if(index1==1){ 
	
	    side1.swapDepths(101);	
	    side1.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side1.swapDepths(1);
		side1.lineStyle(1,nAxesBack,100);
	}
	
	for(k=0; k<3; k++){

		
		if(mids[k]==mid6 || mids[k]==mid4){
			
			index2=1;
			
		}
		
	}
	
	if(index2==1){ 
	    side2.swapDepths(102);
	    side2.lineStyle(1,nAxesFront,100);
		} 
	
	else {
		
		side2.swapDepths(2);
		side2.lineStyle(1,nAxesBack,100);
		
		}
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid6 || mids[k]==mid1){
			
			index3=1;
			
		}
		
	}
	
	if(index3==1){ 
	
	side3.swapDepths(103);
	side3.lineStyle(1,nAxesFront,100);
	} 
	
	else {
		
		side3.swapDepths(3);
		side3.lineStyle(1,nAxesBack,100);
		
		}
	
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid6 || mids[k]==mid2){
			
			index4=1;
			
		}
		
	}
	
	if(index4==1){ 
	
	side4.swapDepths(104);
	side4.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side4.swapDepths(4);
		side4.lineStyle(1,nAxesBack,100);
		
		}
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid6 || mids[k]==mid3){
			
			index5=1;
			
		}
		
	}
	
	if(index5==1){ 
	
	side5.swapDepths(105);
	side5.lineStyle(1,nAxesFront,100);
	} 
	
	else {
		
		side5.swapDepths(5);
		side5.lineStyle(1,nAxesBack,100);
		}
	
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid2 || mids[k]==mid3){
			
			index6=1;
			
		}
		
	}
	
	if(index6==1){ 
	
	side6.swapDepths(106);
	side6.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side6.swapDepths(6);
		side6.lineStyle(1,nAxesBack,100);
		
		}
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid5 || mids[k]==mid3){
			
			index7=1;
			
		}
		
	}
	
	if(index7==1){ 
	
	side7.swapDepths(107);
	side7.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side7.swapDepths(7);
		side7.lineStyle(1,nAxesBack,100);
		
		}
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid5 || mids[k]==mid4){
			
			index8=1;
			
		}
		
	}
	
	if(index8==1){ 
	
	side8.swapDepths(108);
	side8.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side8.swapDepths(8);
		side8.lineStyle(1,nAxesBack,100);
		
		}
	
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid5 || mids[k]==mid1){
			
			index9=1;
			
		}
		
	}
	
	if(index9==1){ 
	
	side9.swapDepths(109);
	side9.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side9.swapDepths(9);
		side9.lineStyle(1,nAxesBack,100);
		
		}
	
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid5 || mids[k]==mid2){
			
			index10=1;
			
		}
		
	}
	
	if(index10==1){ 
	
	side10.swapDepths(110);
	side10.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side10.swapDepths(10);
		side10.lineStyle(1,nAxesBack,100);
		
		}
	
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid1 || mids[k]==mid4){
			
			index11=1;
			
		}
		
	}
	
	if(index11==1){ 
	
	side11.swapDepths(111);
	side11.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side11.swapDepths(11);
		side11.lineStyle(1,nAxesBack,100);
		
		}
	
	
	for(k=0; k<3; k++){
		
		if(mids[k]==mid1 || mids[k]==mid2){
			
			index12=1;
			
		}
		
	}
	
	if(index12==1){ 
	
	side12.swapDepths(112);
	side12.lineStyle(1,nAxesFront,100);
	
	} 
	
	else {
		
		side12.swapDepths(12);
		side12.lineStyle(1,nAxesBack,100);
		
		}
	
	
	if(side1.getDepth()<10){
		
		zLabel._visible=false;
		
		zmaxLabel._visible=false;
		
		zminLabel._visible=false;
		
	} else {
		
		zLabel._visible=true;
		
		zmaxLabel._visible=true;
		
		zminLabel._visible=true;
		
		}
	
	if(side5.getDepth()<10){
		
		yLabel._visible=false;
		
		ymaxLabel._visible=false;
		
		yminLabel._visible=false;
		
	} else {
		
		yLabel._visible=true;
		
		ymaxLabel._visible=true;
		
		yminLabel._visible=true;
	}
	
	if(side2.getDepth()<10){
		
		xLabel._visible=false;
		
		xmaxLabel._visible=false;
		
		xminLabel._visible=false;
		
	} else {
		
		xLabel._visible=true;
		
		xmaxLabel._visible=true;
		
		xminLabel._visible=true;
		
		}
		
		if(Math.abs(xmaxLabel._x)>=nBoardSize/2-32 || Math.abs(xmaxLabel._y)>=nBoardSize/2-18){
			
			xmaxLabel._visible=false;
			
		}
	
	   if(Math.abs(xminLabel._x)>=nBoardSize/2-32 || Math.abs(xminLabel._y)>=nBoardSize/2-18){
			
			xminLabel._visible=false;
			
		}
		
		if(Math.abs(xLabel._x)>=nBoardSize/2-18 || Math.abs(xLabel._y)>=nBoardSize/2-18){
			
			xLabel._visible=false;
			
		}
		
		
		if(Math.abs(ymaxLabel._x)>=nBoardSize/2-32 || Math.abs(ymaxLabel._y)>=nBoardSize/2-18){
			
			ymaxLabel._visible=false;
			
		}
	
	   if(Math.abs(yminLabel._x)>=nBoardSize/2-32 || Math.abs(yminLabel._y)>=nBoardSize/2-18){
			
			yminLabel._visible=false;
			
		}
		
		if(Math.abs(yLabel._x)>=nBoardSize/2-18 || Math.abs(yLabel._y)>=nBoardSize/2-18){
			
			yLabel._visible=false;
			
		}
		
		
		if(Math.abs(zmaxLabel._x)>=nBoardSize/2-32 || Math.abs(zmaxLabel._y)>=nBoardSize/2-18){
			
			zmaxLabel._visible=false;
			
		}
	
	   if(Math.abs(zminLabel._x)>=nBoardSize/2-32 || Math.abs(zminLabel._y)>=nBoardSize/2-18){
			
			zminLabel._visible=false;
			
		}
		
		if(Math.abs(zLabel._x)>=nBoardSize/2-18 || Math.abs(zLabel._y)>=nBoardSize/2-18){
			
			zLabel._visible=false;
			
		}
	
	
	
	side1.moveTo(dp1[0], dp1[1]);
	
	side1.lineTo(dp2[0], dp2[1]);
	
	
	
	side2.moveTo(dp2[0], dp2[1]);
	
	side2.lineTo(dp3[0], dp3[1]);
		
	
	side3.moveTo(dp3[0], dp3[1]);
	
	side3.lineTo(dp4[0], dp4[1]);
	
	
	
	side4.moveTo(dp4[0], dp4[1]);
	
	side4.lineTo(dp5[0], dp5[1]);
	
	
	
	side5.moveTo(dp5[0], dp5[1]);
	
	side5.lineTo(dp2[0], dp2[1]);
	
	
	
	side6.moveTo(dp5[0], dp5[1]);
	
	side6.lineTo(dp6[0], dp6[1]);
	
	
	side7.moveTo(dp6[0], dp6[1]);
	
	side7.lineTo(dp1[0], dp1[1]);
	
	
	side8.moveTo(dp1[0], dp1[1]);
	
	side8.lineTo(dp7[0], dp7[1]);
	
	
	
	side9.moveTo(dp7[0], dp7[1]);
	
	side9.lineTo(dp8[0], dp8[1]);
		
	
	
	side10.moveTo(dp8[0], dp8[1]);
	
	side10.lineTo(dp6[0], dp6[1]);
	
	
	side11.moveTo(dp7[0], dp7[1]);
	
	side11.lineTo(dp3[0], dp3[1]);
	
	
	side12.moveTo(dp8[0], dp8[1]);
	
	side12.lineTo(dp4[0], dp4[1]);
	
	
			
}

    public function resetBoard():Void {
		
		var k:Number;
		
		ErrorBox.text="";
	
	    ErrorBox._visible=false;
				
		xLabel._visible=false;
		xminLabel._visible=false;
		xmaxLabel._visible=false;
		yLabel._visible=false;
		yminLabel._visible=false;
		ymaxLabel._visible=false;
		zLabel._visible=false;
		zminLabel._visible=false;
		zmaxLabel._visible=false;
		
		funArray=[];
		
		pixArray=[];
		
        prepAxes();
	
		patches.clear();
	
	for(k=1;k<=12;k++){
		
	this["side"+k].clear();
	
	}
		
		
	}
	
	 public function showError(mes:String):Void {
		 
	      ErrorBox.text=mes;
		
	      ErrorBox._visible=true;
	
	      xLabel._visible=false;
	
	      yLabel._visible=false;
	
	      zLabel._visible=false;
	
	      zmaxLabel._visible=false;
	
	      zminLabel._visible=false;
	
	      xmaxLabel._visible=false;
	
	      xminLabel._visible=false;
	
	      ymaxLabel._visible=false;
	
	      yminLabel._visible=false;		 
		 
	 }
	 
	
	public function destroy():Void {
		
		
		mcContainer.removeMovieClip();
		
		
	}
		
}

